lkfit is a Python library for fitting.

lkfit comes from a refactoring of [lklib](https://test.pypi.org/project/lklib/)
in order to make it more lightweight. lkfit currently includes just a a few fit
funtions that were supported by lklib.
